@@ -11,7 +11,7 @@ import java.util.EventObject;
  *
  */
 public class JMVCommandEvent extends EventObject {
-    public static enum COMMAND {
+    public enum COMMAND {
         MOVE,
         ZOOM
     }
@@ -28,10 +28,6 @@ public class JMVCommandEvent extends EventObject {
         setCommand(cmd);
     }
 
-    public JMVCommandEvent(Object source) {
-        super(source);
-    }
-
     /**
      * @return the command
      */
